API reference
=============

``appsettings.AppSettings`` class
---------------------------------

.. autoclass:: appsettings.AppSettings
    :members:

``appsettings.Setting`` and subclasses
--------------------------------------

.. autoclass:: appsettings.Setting
    :members:

.. autoclass:: appsettings.BooleanSetting
    :members:

.. autoclass:: appsettings.IntegerSetting
    :members:

.. autoclass:: appsettings.PositiveIntegerSetting
    :members:

.. autoclass:: appsettings.FileSetting
    :members:

.. autoclass:: appsettings.FloatSetting
    :members:

.. autoclass:: appsettings.PositiveFloatSetting
    :members:

``appsettings.IterableSetting`` and subclasses
----------------------------------------------

.. autoclass:: appsettings.IterableSetting
    :members:

.. autoclass:: appsettings.StringSetting
    :members:

.. autoclass:: appsettings.ListSetting
    :members:

.. autoclass:: appsettings.SetSetting
    :members:

.. autoclass:: appsettings.TupleSetting
    :members:

``appsettings.DictSetting`` setting
-----------------------------------

.. autoclass:: appsettings.DictSetting
    :members:

``appsettings.ObjectSetting`` setting
-------------------------------------

.. autoclass:: appsettings.ObjectSetting
    :members:

``appsettings.CallablePathSetting`` setting
-------------------------------------------

.. autoclass:: appsettings.CallablePathSetting
    :members:

``appsettings.NestedDictSetting`` setting
-----------------------------------------

.. autoclass:: appsettings.NestedDictSetting
    :members:

``appsettings.NestedSetting`` setting
-------------------------------------

This setting is deprecated in favor of ``appsettings.NestedDictSetting``.

.. autoclass:: appsettings.NestedSetting
    :members:

``appsettings.NestedListSetting`` setting
-----------------------------------------

.. autoclass:: appsettings.NestedListSetting
    :members:
